ProSHADE: src/proshade Directory Reference

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

proshade Directory Reference

## Files
file | ProSHADE.cpp [code]
| This is the main source file providing the main access class and its functions.
file | ProSHADE.hpp [code]
| This is the main header file providing the main access class and its functions.
file | ProSHADE_data.cpp [code]
| This is the source file containing internal data representation and manipulation structures and functions.
file | ProSHADE_data.hpp [code]
| This is the header file containing internal data representation and manipulation structures and functions.
file | ProSHADE_distances.cpp [code]
| This is the source file containing functions required for computation of shape distances.
file | ProSHADE_distances.hpp [code]
| This is the header file containing declarations of functions required for computation of shape distances.
file | ProSHADE_exceptions.hpp [code]
| This header file contains the ProSHADE_exception class, which is used to report errors occuring during run-time.
file | ProSHADE_io.cpp [code]
| This source file contains the functions required for specifc data format manipulations.
file | ProSHADE_io.hpp [code]
| This header file declares all the functions required for low level file format access.
file | ProSHADE_mapManip.cpp [code]
| This source file contains the functions required for internal map manipulation for various purposes.
file | ProSHADE_mapManip.hpp [code]
| This header file declares the ProSHADE_internal_mapManip namespace, which groups functions for internal map manipulation.
file | ProSHADE_maths.cpp [code]
| This source file contains all the mathematical functions not simply available from elsewhere or modified to work with ProSHADE specific data formats.
file | ProSHADE_maths.hpp [code]
| This header file declares all the functions required for computing various information from the ProSHADE data.
file | ProSHADE_messages.cpp [code]
| This source file contains all user message functions.
file | ProSHADE_messages.hpp [code]
| This header file contains all message function declarations.
file | ProSHADE_misc.cpp [code]
| This source file contains all miscellaneous functions.
file | ProSHADE_misc.hpp [code]
| This header file declares all miscellaneous functions.
file | ProSHADE_overlay.cpp [code]
| This source file contains the functions required for structure overlay computations.
file | ProSHADE_overlay.hpp [code]
| This header file declares the functions required for the structure overlay computation.
file | ProSHADE_peakSearch.cpp [code]
| This source file declares functions required for peak searching and peak position optimisation.
file | ProSHADE_peakSearch.hpp [code]
| This header file declares functions required for 3D map peak searching.
file | ProSHADE_settings.hpp [code]
| This header file declares the ProSHADE_settings class, which is the main information carrying object in ProSHADE.
file | ProSHADE_spheres.cpp [code]
| This source file contains function related to the ProSHADE_sphere class, which generally serve to prepare a shell for SH decomposition.
file | ProSHADE_spheres.hpp [code]
| This header file contains the declarations for the ProSHADE_sphere class.
file | ProSHADE_sphericalHarmonics.cpp [code]
| This source file contains the function required to compute the spherical harmonics decompostion in ProSHADE.
file | ProSHADE_sphericalHarmonics.hpp [code]
| This header file declares the functions required to compute the spherical harmonics decomposition for a particular sphere.
file | ProSHADE_symmetry.cpp [code]
| This source file contains all the functions required to detect symmetry axes and types from the inverse SOFT map.
file | ProSHADE_symmetry.hpp [code]
| This header file declares all the functions required for symmetry detection and construction.
file | ProSHADE_tasks.cpp [code]
| This source file contains the task functions, which drive the computation of a specific task.
file | ProSHADE_tasks.hpp [code]
| This header declares all the taks functions.
file | ProSHADE_typedefs.hpp [code]
| This header contains the type definitions for ProSHADE.
file | ProSHADE_wignerMatrices.cpp [code]
| This source file contains all the functions required to compute the Wigner D matrices.
file | ProSHADE_wignerMatrices.hpp [code]
| This header declares the functions required to compute the Wigner D matrices.